<template>
    <div class="app-container">
        <el-form :model="queryParams" ref="queryForm" :inline="true" v-show="showSearch" label-width="68px">
            <el-form-item label="名称" prop="name">
                <el-input
                    v-model="queryParams.name"
                    placeholder="请输入名称"
                    clearable
                    size="small"
                    @keyup.enter.native="handleQuery"
                    maxlength="36"
                />
            </el-form-item>
            <el-form-item label="上级分类" prop="id">
                <el-select v-model="queryParams.id" filterable clearable placeholder="请选择上级分类" >

                    <el-option
                        v-for="option in options"
                        :label="option.name"
                        :value="option.id"
                    ></el-option>
                    <el-option label="无" value="0"></el-option>
                </el-select>
                </el-form-item>
            <el-form-item label="状态" prop="status">
                <el-select v-model="queryParams.status" placeholder="请选择状态" clearable @keyup.enter.native="handleQuery">
                    <el-option label="启用" :value="0"></el-option>
                    <el-option label="禁用" :value="1"></el-option>
                </el-select>
            </el-form-item>
            <el-form-item>
                <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
                <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
            </el-form-item>
        </el-form>

        <el-row :gutter="10" class="mb8">
            <el-col :span="1.5">
                <el-button
                    type="primary"
                    plain
                    icon="el-icon-plus"
                    size="mini"
                    @click="handleAdd"
                    v-hasPermi="['ActClassification:ActClassification:add']"
                >新增</el-button>
            </el-col>
            <el-col :span="1.5">
                <el-button
                    type="success"
                    plain
                    icon="el-icon-edit"
                    size="mini"
                    :disabled="single"
                    @click="handleUpdate"
                    v-hasPermi="['ActClassification:ActClassification:edit']"
                >修改</el-button>
            </el-col>
            <el-col :span="1.5">
                <el-button
                    type="danger"
                    plain
                    icon="el-icon-delete"
                    size="mini"
                    :disabled="multiple"
                    @click="handleDelete"
                    v-hasPermi="['ActClassification:ActClassification:remove']"
                >删除</el-button>
            </el-col>
            <el-col :span="1.5">
                <el-button
                    type="warning"
                    plain
                    icon="el-icon-download"
                    size="mini"
                    @click="handleExport"
                    v-hasPermi="['ActClassification:ActClassification:export']"
                >导出</el-button>
            </el-col>
            <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
        </el-row>

        <el-table v-loading="loading" :data="ActClassificationList" @selection-change="handleSelectionChange">
            <el-table-column type="selection" width="55" align="center" />
            <el-table-column label="ID" align="center" prop="id" />
            <el-table-column label="名称" align="center" prop="name" />
            <el-table-column label="上级分类" align="center"  >
                <template slot-scope="scope">
                    <div>
                        <template v-if="scope.row.fname === null">
                            无
                        </template>
                        <template v-else>
                            {{ scope.row.fname }}
                        </template>
                    </div>
                </template>
            </el-table-column>

            <el-table-column label="状态" align="center">
                <template slot-scope="scope">
                    <div>
                        <el-switch
                            @change="toggleEnable(scope.row)"
                            v-model="scope.row.status"
                            :active-value="0"
                            :inactive-value="1"
                            active-color="#13ce66"
                            inactive-color="#cccccc">
                        </el-switch>
                    </div>
                </template>
            </el-table-column>
            <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
                <template slot-scope="scope">
                    <el-button
                        size="mini"
                        type="text"
                        icon="el-icon-edit"
                        @click="handleUpdate(scope.row)"
                        v-hasPermi="['ActClassification:ActClassification:edit']"
                    >修改</el-button>
                    <el-button
                        size="mini"
                        type="text"
                        icon="el-icon-delete"
                        @click="handleDelete(scope.row)"
                        v-hasPermi="['ActClassification:ActClassification:remove']"
                    >删除</el-button>
                </template>
            </el-table-column>
        </el-table>

        <pagination
            v-show="total>0"
            :total="total"
            :page.sync="queryParams.pageNum"
            :limit.sync="queryParams.pageSize"
            @pagination="getList"
        />

        <!-- 添加或修改分配信息对话框 -->
        <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
            <el-form ref="form" :model="form" :rules="rules" label-width="80px">
                <el-form-item label="名称" prop="name">
                    <el-input v-model="form.name" placeholder="请输入名称"  maxlength="36" />
                </el-form-item>
                <el-form-item label="父ID" prop="pid" >
                    <el-select v-model="form.pid" filterable placeholder="请输入所属大类"  style="width:380px">
                        <el-option
                            v-for="option in options"
                            :key="option.name"
                            :label="option.name"
                            :value="option.id"
                        ></el-option>
                        <el-option label="无" :value="0"></el-option>
                    </el-select>
                </el-form-item>
                <el-form-item label="状态" prop="status" >
                    <el-select v-model="form.status" placeholder="请选择状态"  style="width:380px" >
                        <el-option label="启用" :value="0"></el-option>
                        <el-option label="禁用" :value="1"></el-option>
                    </el-select>
                </el-form-item>
            </el-form>
            <div slot="footer" class="dialog-footer">
                <el-button type="primary" @click="submitForm">确 定</el-button>
                <el-button @click="cancel">取 消</el-button>
            </div>
        </el-dialog>
    </div>
</template>

<script>
import { listActClassification, savePid,toggleEnable,toggleDisable,getActClassification, delActClassification, addActClassification, updateActClassification, exportActClassification } from "@/api/ActClassification/ActClassification";

export default {
    name: "ActClassification",
    components: {
    },
    data() {
        return {
            // 遮罩层
            loading: true,
            // 选中数组
            ids: [],
            // 非单个禁用
            single: true,
            // 非多个禁用
            multiple: true,
            // 显示搜索条件
            showSearch: true,
            // 总条数
            total: 0,
            // 分配信息表格数据
            ActClassificationList: [],
            // 弹出层标题
            title: "",
            // 是否显示弹出层
            open: false,
            options:[],
            // 查询参数
            queryParams: {
                pageNum: 1,
                pageSize: 10,
                name: null,
                pid: null,
                status: null,
            },
            // 表单参数
            form: {},
            // 表单校验
            rules: {
            }
        };
    },
    created() {
        this.getList();

    },
    mounted() {
        this.fetchOptions();
    },
    methods: {

        /**启用 */
        toggleEnable(ActClassification){
            console.log('你点击了【' + ActClassification.name+'】的开关控件，当前开关值:' + ActClassification.status);
            let enableText=['启用','禁用'];
            if(ActClassification.status === 0) {
                toggleEnable(ActClassification.id).then((response) =>{

                    if(response.code === 200){
                        let message = '操作成功，已经将【' + ActClassification.name +'】的状态改为【'+ enableText[ActClassification.status] +'】 !';
                        this.$message({
                            message: message,
                            type:'success'
                        });
                    }else {
                        this.$message.error(response.message);
                    }
                });
            }else {
                toggleDisable(ActClassification.id).then((response) =>{
                    if(response.code === 200){
                        let message = '操作成功，已经将【' + ActClassification.name +'】的状态改为【'+ enableText[ActClassification.status] +'】 !';
                        this.$message({
                            message: message,
                            type:'error'
                        });
                    }else {
                        this.getList();
                        this.$message.error(response.code);
                    }
                });
            }
        },

        /** 查询上级关联关系*/
        fetchOptions() {
            savePid().then(response => {
                console.log(response.rows)
                this.options = response.rows;
            });
        },
        /** 查询分配信息列表 */
        getList() {
            this.loading = true;
            listActClassification(this.queryParams).then(response => {
                this.ActClassificationList = response.rows;
                this.total = response.total;
                this.loading = false;
            });
        },
        // 取消按钮
        cancel() {
            this.open = false;
            this.reset();
        },
        // 表单重置
        reset() {
            this.form = {
                id: null,
                name: null,
                pid: null,
                status: "0",
                createBy: null,
                createTime: null,
                updateBy: null,
                updateTime: null
            };
            this.resetForm("form");
        },
        /** 搜索按钮操作 */
        handleQuery() {
            this.queryParams.pageNum = 1;
            this.getList();
        },
        /** 重置按钮操作 */
        resetQuery() {
            this.resetForm("queryForm");
            this.handleQuery();
        },
        // 多选框选中数据
        handleSelectionChange(selection) {
            this.ids = selection.map(item => item.id)
            this.single = selection.length!==1
            this.multiple = !selection.length
        },
        /** 新增按钮操作 */
        handleAdd() {
            this.reset();
            this.open = true;
            this.title = "添加分配信息";
        },
        /** 修改按钮操作 */
        handleUpdate(row) {
            this.reset();
            const id = row.id || this.ids
            getActClassification(id).then(response => {
                this.form = response.data;
                this.open = true;
                this.title = "修改分配信息";
            });
        },
        /** 提交按钮 */
        submitForm() {
            this.$refs["form"].validate(valid => {
                if (valid) {
                    if (this.form.id != null) {
                        updateActClassification(this.form).then(response => {
                            this.msgSuccess("修改成功");
                            this.open = false;
                            this.getList();
                        });
                    } else {
                        addActClassification(this.form).then(response => {
                            this.msgSuccess("新增成功");
                            this.open = false;
                            this.getList();
                        });
                    }
                }
            });
        },
        /** 删除按钮操作 */
        handleDelete(row) {
            const ids = row.id || this.ids;
            this.$confirm('是否确认删除分配信息编号为"' + ids + '"的数据项?', "警告", {
                confirmButtonText: "确定",
                cancelButtonText: "取消",
                type: "warning"
            }).then(function() {
                return delActClassification(ids);
            }).then(() => {
                this.getList();
                this.msgSuccess("删除成功");
            })
        },
        /** 导出按钮操作 */
        handleExport() {
            const queryParams = this.queryParams;
            this.$confirm('是否确认导出所有分配信息数据项?', "警告", {
                confirmButtonText: "确定",
                cancelButtonText: "取消",
                type: "warning"
            }).then(function() {
                return exportActClassification(queryParams);
            }).then(response => {
                this.download(response.msg);
            })
        }
    }
};
</script>
